@@ -1,7 +1,7 @@
 import click
-from common_func import generate_data as gd
-from common_func import main as m
-from common_func import load_testing_measurements as ms
+from .common_func import generate_data as gd
+from .common_func import main as m
+from .common_func import load_testing_measurements as ms
 import os
 
 
